Skip to main contentCrate runi_log
Source - instrument
- Attach a span to a
std::future::Future. - span
- Spans represent periods of time in which a program was executing in a
particular context.
- debug
- Constructs an event at the debug level.
- error
- Constructs an event at the error level.
- info
- Constructs an event at the info level.
- span
- Constructs a new span.
- trace
- Constructs an event at the trace level.
- warn
- Constructs an event at the warn level.
- Level
- Describes the level of verbosity of a span or event.
- Span
- A handle representing a span, with the capability to enter the span if it
exists.
- init
- Initialize logging with sensible defaults.
- init_with_env
- Initialize logging with a custom env var name for the filter.
- init_with_level
- Initialize logging with a specific level string (e.g., “debug”, “warn”).
- instrument
- Instruments a function to create and enter a
tracing span every time
the function is called.